@@ -3,24 +3,20 @@ package YAML::LibYAML::API;
 use strict;
 use warnings;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
-use constant {
-    YAML_ANY_SCALAR_STYLE           => 'any',
-    YAML_PLAIN_SCALAR_STYLE         => ':',
-    YAML_SINGLE_QUOTED_SCALAR_STYLE => "'",
-    YAML_DOUBLE_QUOTED_SCALAR_STYLE => '"',
-    YAML_LITERAL_SCALAR_STYLE       => '|',
-    YAML_FOLDED_SCALAR_STYLE        => '>',
+use YAML::PP::Common qw/
+    YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE
+    YAML_SINGLE_QUOTED_SCALAR_STYLE YAML_DOUBLE_QUOTED_SCALAR_STYLE
+    YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE
+    YAML_QUOTED_SCALAR_STYLE
 
-    YAML_ANY_SEQUENCE_STYLE   => 'any',
-    YAML_BLOCK_SEQUENCE_STYLE => 'block',
-    YAML_FLOW_SEQUENCE_STYLE  => 'flow',
+    YAML_ANY_SEQUENCE_STYLE
+    YAML_BLOCK_SEQUENCE_STYLE YAML_FLOW_SEQUENCE_STYLE
 
-    YAML_ANY_MAPPING_STYLE   => 'any',
-    YAML_BLOCK_MAPPING_STYLE => 'block',
-    YAML_FLOW_MAPPING_STYLE  => 'flow',
-};
+    YAML_ANY_MAPPING_STYLE
+    YAML_BLOCK_MAPPING_STYLE YAML_FLOW_MAPPING_STYLE
+/;
 
 my @scalar_styles = (
     YAML_ANY_SCALAR_STYLE,
